@@ -55,7 +55,7 @@ public:
     MainWindow();
     ~MainWindow();
 
-    PluginList pluginList() const Q_DECL_OVERRIDE
+    PluginList pluginList() const override
     {
         return mPlugins;
     }
@@ -64,10 +64,11 @@ public:
     static bool pluginActionWeightLessThan(const QAction *left, const QAction *right);
     static bool pluginWeightLessThan(const KontactInterface::Plugin *left,
                                      const KontactInterface::Plugin *right);
+    void showHideSideBar(bool show);
 
 public Q_SLOTS:
-    void selectPlugin(KontactInterface::Plugin *plugin) Q_DECL_OVERRIDE;
-    Q_SCRIPTABLE void selectPlugin(const QString &pluginName) Q_DECL_OVERRIDE;
+    void selectPlugin(KontactInterface::Plugin *plugin) override;
+    Q_SCRIPTABLE void selectPlugin(const QString &pluginName) override;
     void slotActionTriggered();
 
     void updateConfig();
@@ -100,21 +101,23 @@ private:
     void updateShortcuts();
     bool removePlugin(const KPluginInfo &);
     void addPlugin(KontactInterface::Plugin *plugin);
-    void partLoaded(KontactInterface::Plugin *plugin, KParts::ReadOnlyPart *part) Q_DECL_OVERRIDE;
+    void partLoaded(KontactInterface::Plugin *plugin, KParts::ReadOnlyPart *part) override;
     void setupActions();
-    bool queryClose() Q_DECL_OVERRIDE;
-    void readProperties(const KConfigGroup &config) Q_DECL_OVERRIDE;
-    void saveProperties(KConfigGroup &config) Q_DECL_OVERRIDE;
+    bool queryClose() override;
+    void readProperties(const KConfigGroup &config) override;
+    void saveProperties(KConfigGroup &config) override;
     void paintAboutScreen(const QString &templateName, const QVariantHash &data);
     static QVariantHash introductionData();
     KToolBar *findToolBar(const char *name);
+    QString showHideSideBarMessage(bool hidden) const;
 
 private Q_SLOTS:
     void pluginsChanged();
 
     void configureShortcuts();
-    void configureToolbars() Q_DECL_OVERRIDE;
+    void configureToolbars() override;
     void slotShowHideSideBar();
+    void slotSplitterMoved(int pos, int index);
 
 private:
     void setHelpText(QAction *action, const QString &text);
@@ -142,6 +145,8 @@ private:
 
     AboutDialog *mAboutDialog;
     bool mReallyClose;
+    int mSaveSideBarWidth;
+    QAction *mShowHideAction;
 };
 
 }
